# HarukaBot-Red
 基于[HarukaBot](https://github.com/SK-415/HarukaBot)，适配Red协议

因[`go-cqhttp`停止维护](https://github.com/Mrs4s/go-cqhttp/issues/2471)，
且替代方案`chronocat`不支持`onebot`协议，故修改得到此版本，方便原`hb`用户迁移。

> README完善中，点个star为作者加速